@@ -1,11 +1,12 @@
 package kinesis
 
 import (
+	"context"
 	"time"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/kinesis"
-	"github.com/aws/aws-sdk-go/service/kinesis/kinesisiface"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/service/kinesis"
+	"github.com/aws/aws-sdk-go-v2/service/kinesis/types"
 	"github.com/gofrs/uuid"
 	"github.com/influxdata/telegraf"
 	internalaws "github.com/influxdata/telegraf/config/aws"
@@ -26,7 +27,7 @@ type (
 
 		Log        telegraf.Logger `toml:"-"`
 		serializer serializers.Serializer
-		svc        kinesisiface.KinesisAPI
+		svc        kinesisClient
 
 		internalaws.CredentialConfig
 	}
@@ -38,6 +39,10 @@ type (
 	}
 )
 
+type kinesisClient interface {
+	PutRecords(context.Context, *kinesis.PutRecordsInput, ...func(*kinesis.Options)) (*kinesis.PutRecordsOutput, error)
+}
+
 var sampleConfig = `
   ## Amazon REGION of kinesis endpoint.
   region = "ap-southeast-2"
@@ -126,9 +131,14 @@ func (k *KinesisOutput) Connect() error {
 		k.Log.Infof("Establishing a connection to Kinesis in %s", k.Region)
 	}
 
-	svc := kinesis.New(k.CredentialConfig.Credentials())
+	cfg, err := k.CredentialConfig.Credentials()
+	if err != nil {
+		return err
+	}
 
-	_, err := svc.DescribeStreamSummary(&kinesis.DescribeStreamSummaryInput{
+	svc := kinesis.NewFromConfig(cfg)
+
+	_, err = svc.DescribeStreamSummary(context.Background(), &kinesis.DescribeStreamSummaryInput{
 		StreamName: aws.String(k.StreamName),
 	})
 	k.svc = svc
@@ -143,14 +153,14 @@ func (k *KinesisOutput) SetSerializer(serializer serializers.Serializer) {
 	k.serializer = serializer
 }
 
-func (k *KinesisOutput) writeKinesis(r []*kinesis.PutRecordsRequestEntry) time.Duration {
+func (k *KinesisOutput) writeKinesis(r []types.PutRecordsRequestEntry) time.Duration {
 	start := time.Now()
 	payload := &kinesis.PutRecordsInput{
 		Records:    r,
 		StreamName: aws.String(k.StreamName),
 	}
 
-	resp, err := k.svc.PutRecords(payload)
+	resp, err := k.svc.PutRecords(context.Background(), payload)
 	if err != nil {
 		k.Log.Errorf("Unable to write to Kinesis : %s", err.Error())
 		return time.Since(start)
@@ -210,7 +220,7 @@ func (k *KinesisOutput) Write(metrics []telegraf.Metric) error {
 		return nil
 	}
 
-	r := []*kinesis.PutRecordsRequestEntry{}
+	r := []types.PutRecordsRequestEntry{}
 
 	for _, metric := range metrics {
 		sz++
@@ -223,12 +233,12 @@ func (k *KinesisOutput) Write(metrics []telegraf.Metric) error {
 
 		partitionKey := k.getPartitionKey(metric)
 
-		d := kinesis.PutRecordsRequestEntry{
+		d := types.PutRecordsRequestEntry{
 			Data:         values,
 			PartitionKey: aws.String(partitionKey),
 		}
 
-		r = append(r, &d)
+		r = append(r, d)
 
 		if sz == maxRecordsPerRequest {
 			elapsed := k.writeKinesis(r)
